#!/bin/bash
# Claude Code カスタムヘルプのセットアップスクリプト

set -e

# カラー定義
GREEN='\033[0;32m'
YELLOW='\033[1;33m'
RED='\033[0;31m'
NC='\033[0m'

echo -e "${GREEN}Claude Code カスタムヘルプをセットアップします${NC}"

# スクリプトディレクトリの確認
SCRIPT_DIR="$HOME/git/claude/scripts"
if [[ ! -d "$SCRIPT_DIR" ]]; then
    echo -e "${YELLOW}スクリプトディレクトリを作成します...${NC}"
    mkdir -p "$SCRIPT_DIR"
fi

# 実行権限の付与
echo -e "${GREEN}実行権限を設定中...${NC}"
chmod +x "$SCRIPT_DIR"/*.sh 2>/dev/null || true

# .zshrcへの追加確認
ZSHRC="$HOME/.zshrc"
SOURCE_LINE="source \"\$HOME/git/claude/scripts/claude-zsh-functions.sh\""

if grep -q "claude-zsh-functions.sh" "$ZSHRC" 2>/dev/null; then
    echo -e "${YELLOW}既に.zshrcに設定があります${NC}"
else
    echo -e "${GREEN}.zshrcに設定を追加しますか？${NC}"
    read -p "続行しますか? (y/N): " -n 1 -r
    echo
    if [[ $REPLY =~ ^[Yy]$ ]]; then
        echo "" >> "$ZSHRC"
        echo "# Claude Code Helper Functions" >> "$ZSHRC"
        echo "$SOURCE_LINE" >> "$ZSHRC"
        echo -e "${GREEN}✓ .zshrcに追加しました${NC}"
    else
        echo -e "${YELLOW}手動で以下を.zshrcに追加してください:${NC}"
        echo "$SOURCE_LINE"
    fi
fi

# テスト実行
echo -e "\n${GREEN}セットアップ完了！${NC}"
echo -e "${YELLOW}以下のコマンドでテストしてください:${NC}"
echo "  source ~/.zshrc"
echo "  claude-help"
echo ""
echo -e "${GREEN}利用可能なコマンド:${NC}"
echo "  claude-help    - 拡張ヘルプ表示"
echo "  ch            - claude-helpの短縮形"
echo "  cr            - クイックリファレンス"
echo "  cs            - 安全モードで起動"
echo "  claude-docs   - 公式ドキュメントを開く"